@@ -5,5 +5,11 @@ __all__ = [
 ]
 
 class NTFYServer():
+    """
+    Attributes
+    ----------
+    url: :class:`str`
+        server's url
+    """
     def __init__(self, url: str):
         self.url: Final[str] = url
